@@ -7,10 +7,10 @@
 import json
 import os
 import time
+import traceback
 
 from gi.repository import GdkPixbuf
 from gi.repository import Gtk
-import html2text
 
 from kuwo import Config
 _ = Config._
@@ -18,6 +18,13 @@ from kuwo import Net
 from kuwo import Widgets
 from kuwo.log import logger
 
+try:
+    import html2text
+    html2text_imported = True
+except ImportError:
+    logger.warn(traceback.exec())
+    html2text_imported = False
+
 
 class InfoLabel(Gtk.Label):
     def __init__(self, grid, pref, left, top):
@@ -484,7 +491,7 @@ class Artists(Gtk.Box):
         def _append_artist_songs(songs_args, error=None):
             if error or not songs_args or not songs_args[1]:
                 logger.error('append_artist_songs(): %s, %s' %
-                             (self.artist_songs_total, error))
+                             (songs_args, error))
                 return
             songs, self.artist_songs_total = songs_args
             for song in songs:
@@ -524,7 +531,7 @@ class Artists(Gtk.Box):
             albums, self.artist_albums_total = albums_args
             if error or self.artist_albums_total == 0:
                 logger.error('append_arttist_albums(): %s, %s' %
-                             (self.artist_albums_taotal, error))
+                             (self.artist_albums_total, error))
                 return
             urls = []
             tree_iters = []
@@ -672,8 +679,12 @@ class Artists(Gtk.Box):
             self.artist_info_gender.set(info, 'gender',)
             self.artist_info_constellation.set(info, 'constellation')
             if info and 'info' in info:
-                self.artist_info_textbuffer.set_text(
-                        html2text.html2text(info['info']))
+                if html2text_imported:
+                    self.artist_info_textbuffer.set_text(
+                            html2text.html2text(info['info']))
+                else:
+                    self.artist_info_textbuffer.set_text(
+                            Widgets.escape(info['info']))
             else:
                 self.artist_info_textbuffer.set_text('')
 
