@@ -120,7 +120,7 @@ class Lrc(Gtk.Notebook):
         self.old_line_iter = None
         self.old_timestamp = -5
         if not lrc_txt:
-            self.lrc_buf.set_text(_('No lrc available'))
+            self.lrc_buf.set_text(_('No lyrics available'))
             self.lrc_obj = None
             self.app.osdlrc.set_lrc(self.lrc_obj)
             return
@@ -128,7 +128,7 @@ class Lrc(Gtk.Notebook):
         self.app.osdlrc.set_lrc(self.lrc_obj)
         if not self.lrc_obj:
             logger.warn('set_lrc(): failed to parse lrc.')
-            self.lrc_buf.set_text(_('No lrc available'))
+            self.lrc_buf.set_text(_('No lyrics available'))
             return
         lrc_content = [l[1] for l in self.lrc_obj]
 
@@ -137,6 +137,13 @@ class Lrc(Gtk.Notebook):
         self.lrc_buf.set_text('\n'.join(lrc_content))
         self.lrc_window.get_vadjustment().set_value(0)
 
+    def reset_tags(self):
+        if not self.lrc_obj:
+            return
+        iter_start = self.lrc_buf.get_start_iter()
+        iter_end = self.lrc_buf.get_end_iter()
+        self.lrc_buf.remove_tag(self.highlighted_tag, iter_start, iter_end)
+
     def sync_lrc(self, timestamp):
         if not self.lrc_obj or len(self.lrc_obj) <= self.old_line_num + 1:
             return
