@@ -5,6 +5,7 @@
 # in the LICENSE file.
 
 import sys
+import time
 
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
@@ -59,6 +60,10 @@ class Player(Gtk.Box):
         self.adj_timeout = 0
         self.recommend_imgs = None
         self.curr_song = None
+        self.fullscreen_sid = 0
+        self.fullscreen_timestamp = 0
+        self.default_cursor = None
+        self.blank_cursor = Gdk.Cursor.new(Gdk.CursorType.BLANK_CURSOR)
 
         # use this to keep Net.AsyncSong object
         self.async_song = None
@@ -437,6 +442,7 @@ class Player(Gtk.Box):
             button.set_icon_name('media-playlist-repeat-symbolic')
 
     def on_scale_change_value(self, scale, scroll_type, value):
+        self.app.lrc.reset_tags()
         self.seek_cb(value)
 
     def on_volume_value_changed(self, volume_button, volume):
@@ -565,21 +571,66 @@ class Player(Gtk.Box):
     # Fullscreen
     def toggle_fullscreen(self):
         '''Switch between fullscreen and unfullscreen mode.'''
+
+        def hide_control_panel_and_label(timestamp):
+            if self.fullscreen_sid > 0:
+                gdk_window.set_cursor(self.blank_cursor)
+            if (timestamp == self.fullscreen_timestamp and
+                    self.fullscreen_sid > 0):
+                self.hide()
+                GLib.timeout_add(100, self.playbin.expose)
+                self.app.notebook.set_show_tabs(False)
+
+        def on_window_motion_notified(window, event):
+            window.get_window().set_cursor(self.default_cursor)
+            if self.fullscreen_sid == 0:
+                return
+            lower = 70
+            upper = window.get_size()[1] - 40
+            if lower < event.y < upper:
+                GLib.timeout_add(2000,
+                        lambda *args: gdk_window.set_cursor(self.blank_cursor))
+            else:
+                self.show_all()
+                self.app.notebook.set_show_tabs(True)
+
+            # Delay 2 seconds to hide them
+            self.fullscreen_timestamp = time.time()
+            GLib.timeout_add(100, self.playbin.expose)
+            GLib.timeout_add(2000, hide_control_panel_and_label,
+                             self.fullscreen_timestamp)
+
         window = self.app.window
+        gdk_window = window.get_window()
         button = self.fullscreen_btn
+        if not self.default_cursor:
+            self.default_cursor = gdk_window.get_cursor()
+        if not self.default_cursor:
+            self.default_cursor = Gdk.Cursor.new(Gdk.CursorType.ARROW)
+
         if not button.get_active():
         # unfullscreen
+            window.unfullscreen()
             button.set_icon_name('view-fullscreen-symbolic')
             window.realize()
-            window.unfullscreen()
-            #self.playbin.expose()
+            self.playbin.expose()
+            self.show()
+            self.app.notebook.set_show_tabs(True)
+            self.fullscreen_sid = 0
+            gdk_window.set_cursor(self.default_cursor)
         else:
         # fullscreen
-            button.set_icon_name('view-restore-symbolic')
             self.app.popup_page(self.app.lrc.app_page)
             window.realize()
             window.fullscreen()
-            #self.playbin.expose_fullscreen()
+            button.set_icon_name('view-restore-symbolic')
+            self.playbin.expose_fullscreen()
+
+            self.hide()
+            self.app.notebook.set_show_tabs(False)
+            gdk_window.set_cursor(self.blank_cursor)
+            self.fullscreen_sid = window.connect('motion-notify-event',
+                                                 on_window_motion_notified)
 
     def on_window_key_pressed(self, widget, event):
         # press Esc to exit fullscreen mode
@@ -587,8 +638,7 @@ class Player(Gtk.Box):
             self.fullscreen_btn.set_active(False)
         # press F11 to toggle fullscreen mode
         elif event.keyval == Gdk.KEY_F11:
-            self.fullscreen_btn.set_active(
-                    not self.fullscreen_btn.get_active())
+            self.fullscreen_btn.set_active(not self.fullscreen_btn.get_active())
 
     def on_fullscreen_button_toggled(self, button):
         self.toggle_fullscreen()
@@ -633,7 +683,6 @@ class Player(Gtk.Box):
         dialog.run()
         dialog.destroy()
         self.app.load_styles()
-        self.app.reset_notebook_tabs()
         self.app.init_status_icon()
         self.app.lrc.update_highlighted_tag()
         self.app.shortcut.rebind_keys()
