@@ -178,15 +178,15 @@ class Search(Gtk.Box):
                 urls, tree_iters = [], []
                 for artist in artists:
                     tree_iter = self.liststore_artists.append([
-                        self.app.theme['anonymous'],
+                        Config.ANONYMOUS_PIXBUF,
                         Widgets.unescape(artist['ARTIST']),
                         int(artist['ARTISTID']),
                         Widgets.unescape(artist['COUNTRY']),
                     ])
                     tree_iters.append(tree_iter)
                     urls.append(artist['PICPATH'])
-                Net.update_artist_logos(self.liststore_artists, 0,
-                                        tree_iters, urls)
+                Net.async_call(Net.update_artist_logos, self.liststore_artists,
+                               0, tree_iters, urls)
             else:
                 logger.error('show_artists(): %s, %s' %
                              (self.artists_total, error))
@@ -209,7 +209,7 @@ class Search(Gtk.Box):
                     tooltip = Widgets.escape(album.get('info',
                                              album['name']))
                     tree_iter = self.liststore_albums.append([
-                        self.app.theme['anonymous'],
+                        Config.ANONYMOUS_PIXBUF,
                         Widgets.unescape(album['name']),
                         int(album['albumid']),
                         Widgets.unescape(album['artist']),
@@ -218,8 +218,8 @@ class Search(Gtk.Box):
                     ])
                     tree_iters.append(tree_iter)
                     urls.append(album['pic'])
-                Net.update_album_covers(self.liststore_albums, 0,
-                                        tree_iters, urls)
+                Net.async_call(Net.update_album_covers, self.liststore_albums,
+                               0, tree_iters, urls)
             else:
                 logger.error('show_albums: %s, %s' % (self.albums_total, error))
 
